pub struct AggregationOperation {
pub field: String,
pub op: AggregationOpType,
pub alias: Option<String>,
pub expand_array: Option<bool>,
}Expand description
AggregationOperation : An operation that will be applied on a field
Fields
field: StringThe field to operate on
op: AggregationOpTypealias: Option<String>Optional alias for the output; if not provided, a default alias is computed
expand_array: Option<bool>Implementations
Sourceimpl AggregationOperation
impl AggregationOperation
Sourcepub fn new(field: String, op: AggregationOpType) -> AggregationOperation
pub fn new(field: String, op: AggregationOpType) -> AggregationOperation
An operation that will be applied on a field