pub struct AggregationResponse {
pub status: ApiStatus,
pub data: Vec<AggregationItem>,
pub stats: Option<Box<AggregationResponseStats>>,
}Expand description
AggregationResponse : The API response returns the aggregated data along with simple stats
Fields
status: ApiStatusdata: Vec<AggregationItem>stats: Option<Box<AggregationResponseStats>>Implementations
Sourceimpl AggregationResponse
impl AggregationResponse
Sourcepub fn new(status: ApiStatus, data: Vec<AggregationItem>) -> AggregationResponse
pub fn new(status: ApiStatus, data: Vec<AggregationItem>) -> AggregationResponse
The API response returns the aggregated data along with simple stats