pub struct AggregationValue {
pub groups: Option<HashMap<String, String>>,
pub string_value: Option<String>,
pub numeric_value: Option<f64>,
pub distinct_count: Option<i64>,
pub distinct_counts: Option<HashMap<String, f64>>,
}Fields
groups: Option<HashMap<String, String>>Construct a type with a set of properties K of type T
string_value: Option<String>numeric_value: Option<f64>distinct_count: Option<i64>distinct_counts: Option<HashMap<String, f64>>Construct a type with a set of properties K of type T
Implementations
Sourceimpl AggregationValue
impl AggregationValue
pub fn new() -> AggregationValue