pub struct CreateEmailTemplateBody {
pub email_template_id: String,
pub display_name: String,
pub ejs: String,
pub domain: Option<String>,
pub translation_overrides_by_locale: Option<HashMap<String, HashMap<String, String>>>,
pub test_data: Option<HashMap<String, Value>>,
}Fields
email_template_id: Stringdisplay_name: Stringejs: Stringdomain: Option<String>translation_overrides_by_locale: Option<HashMap<String, HashMap<String, String>>>Construct a type with a set of properties K of type T
test_data: Option<HashMap<String, Value>>Construct a type with a set of properties K of type T
Implementations