pub struct HeaderAccountNotification {
pub _id: String,
pub title: String,
pub message: String,
pub messages_by_locale: Option<HashMap<String, String>>,
pub dates: Option<HashMap<String, String>>,
pub severity: String,
pub link_url: Option<String>,
pub link_text: Option<String>,
pub created_at: String,
}Fields
_id: Stringtitle: Stringmessage: Stringmessages_by_locale: Option<HashMap<String, String>>Construct a type with a set of properties K of type T
dates: Option<HashMap<String, String>>Construct a type with a set of properties K of type T
severity: Stringlink_url: Option<String>link_text: Option<String>created_at: StringImplementations