PublicComment

Struct PublicComment 

pub struct PublicComment {
Show 39 fields pub _id: String, pub user_id: Option<Option<String>>, pub commenter_name: String, pub commenter_link: Option<Option<String>>, pub comment_html: String, pub parent_id: Option<Option<String>>, pub date: Option<String>, pub votes: Option<Option<i32>>, pub votes_up: Option<Option<i32>>, pub votes_down: Option<Option<i32>>, pub verified: bool, pub avatar_src: Option<Option<String>>, pub has_images: Option<bool>, pub is_by_admin: Option<bool>, pub is_by_moderator: Option<bool>, pub is_pinned: Option<Option<bool>>, pub is_locked: Option<Option<bool>>, pub display_label: Option<Option<String>>, pub rating: Option<Option<f64>>, pub badges: Option<Option<Vec<CommentUserBadgeInfo>>>, pub view_count: Option<Option<i64>>, pub is_deleted: Option<bool>, pub is_deleted_user: Option<bool>, pub is_spam: Option<bool>, pub anon_user_id: Option<Option<String>>, pub feedback_ids: Option<Vec<String>>, pub requires_verification: Option<bool>, pub edit_key: Option<String>, pub approved: Option<bool>, pub is_unread: Option<bool>, pub my_vote_id: Option<String>, pub is_voted_down: Option<bool>, pub is_voted_up: Option<bool>, pub has_children: Option<bool>, pub nested_children_count: Option<i32>, pub child_count: Option<i32>, pub children: Option<Vec<PublicComment>>, pub is_flagged: Option<bool>, pub is_blocked: Option<bool>,
}

Fields

_id: Stringuser_id: Option<Option<String>>commenter_name: Stringcommenter_link: Option<Option<String>>comment_html: Stringparent_id: Option<Option<String>>date: Option<String>votes: Option<Option<i32>>votes_up: Option<Option<i32>>votes_down: Option<Option<i32>>verified: boolavatar_src: Option<Option<String>>has_images: Option<bool>is_by_admin: Option<bool>is_by_moderator: Option<bool>is_pinned: Option<Option<bool>>is_locked: Option<Option<bool>>display_label: Option<Option<String>>rating: Option<Option<f64>>badges: Option<Option<Vec<CommentUserBadgeInfo>>>view_count: Option<Option<i64>>is_deleted: Option<bool>is_deleted_user: Option<bool>is_spam: Option<bool>anon_user_id: Option<Option<String>>feedback_ids: Option<Vec<String>>requires_verification: Option<bool>edit_key: Option<String>approved: Option<bool>is_unread: Option<bool>my_vote_id: Option<String>is_voted_down: Option<bool>is_voted_up: Option<bool>has_children: Option<bool>

This is always set when asTree=true

nested_children_count: Option<i32>

The total nested child count included in this response (may be more available w/ pagination) Only set with asTree=true, otherwise this will be null.

child_count: Option<i32>

You must ask the API to count children (with asTree=true&countChildren=true), otherwise this will be null. This will be the complete direct child count, whereas children may only contain a subset based on pagination.

children: Option<Vec<PublicComment>>is_flagged: Option<bool>is_blocked: Option<bool>

Implementations

Source

impl PublicComment

pub fn new( _id: String, commenter_name: String, comment_html: String, date: Option<String>, verified: bool, ) -> PublicComment