pub struct RenderEmailTemplateBody {
pub email_template_id: String,
pub ejs: String,
pub test_data: Option<HashMap<String, Value>>,
pub translation_overrides_by_locale: Option<HashMap<String, HashMap<String, String>>>,
}Fields
email_template_id: Stringejs: Stringtest_data: Option<HashMap<String, Value>>Construct a type with a set of properties K of type T
translation_overrides_by_locale: Option<HashMap<String, HashMap<String, String>>>Construct a type with a set of properties K of type T
Implementations
Sourceimpl RenderEmailTemplateBody
impl RenderEmailTemplateBody
pub fn new(email_template_id: String, ejs: String) -> RenderEmailTemplateBody