pub struct SimpleSSOUserData {
pub id: Option<String>,
pub locale: Option<String>,
pub display_name: Option<String>,
pub display_label: Option<String>,
pub is_profile_activity_private: Option<bool>,
pub username: String,
pub email: String,
pub avatar: String,
pub website_url: Option<String>,
}Fields
id: Option<String>If you don’t set id, it defaults to their email.
locale: Option<String>Their locale, for email notifications etc, in the format “en_us”.
display_name: Option<String>Set a non-unique name (since username must be unique within your tenant).
display_label: Option<String>Show a nice label with their comments, like “VIP User”.
is_profile_activity_private: Option<bool>Defaults to true when null.
username: StringThis must be unique when paired with an email.
email: StringThe user’s email.
avatar: StringThe user’s avatar.
website_url: Option<String>The user’s website, blog, or personal account page to show with their comments.
Implementations